@@ -25,10 +25,9 @@
 # adding a 'SHOW WARNINGS' after the statement.
 
 set sql_mode='';
-set sql_safe_updates='OFF';
-set storage_engine=Aria;
+set default_storage_engine=Aria;
 set enforce_storage_engine=NULL;
-set alter_algorithm='DEFAULT';
+set alter_algorithm=DEFAULT;
 
 set @have_innodb= (select count(engine) from information_schema.engines where engine='INNODB' and support != 'NO');
 
@@ -180,11 +179,6 @@ UPDATE user
   SET plugin='unix_socket' WHERE plugin='auth_socket';
 DELETE FROM plugin
   WHERE name='auth_socket';
-# Delete plugins that are now inbuilt but might not have been before (MDEV-32043)
-DELETE plugin
-  FROM information_schema.PLUGINS is_p
-  JOIN plugin ON plugin.name = is_p.PLUGIN_NAME
-  WHERE is_p.PLUGIN_LIBRARY IS NULL;
 
 ALTER TABLE user
   MODIFY Password char(41) character set latin1 collate latin1_bin NOT NULL default '',
@@ -245,6 +239,7 @@ SET GLOBAL general_log = 'OFF';
 ALTER TABLE general_log
   MODIFY event_time TIMESTAMP(6) NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
   MODIFY user_host MEDIUMTEXT NOT NULL,
+  MODIFY thread_id INTEGER NOT NULL,
   MODIFY server_id INTEGER UNSIGNED NOT NULL,
   MODIFY command_type VARCHAR(64) NOT NULL,
   MODIFY argument MEDIUMTEXT NOT NULL,
@@ -253,23 +248,23 @@ SET GLOBAL general_log = @old_log_state;
 
 SET @old_log_state = @@global.slow_query_log;
 SET GLOBAL slow_query_log = 'OFF';
+ALTER TABLE slow_log
+  ADD COLUMN thread_id BIGINT(21) UNSIGNED NOT NULL AFTER sql_text;
+ALTER TABLE slow_log
+  ADD COLUMN rows_affected INTEGER NOT NULL AFTER thread_id;
 ALTER TABLE slow_log
   MODIFY start_time TIMESTAMP(6) NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
   MODIFY user_host MEDIUMTEXT NOT NULL,
   MODIFY query_time TIME(6) NOT NULL,
   MODIFY lock_time TIME(6) NOT NULL,
-  MODIFY rows_sent BIGINT UNSIGNED NOT NULL,
-  MODIFY rows_examined BIGINT UNSIGNED NOT NULL,
+  MODIFY rows_sent INTEGER NOT NULL,
+  MODIFY rows_examined INTEGER NOT NULL,
   MODIFY db VARCHAR(512) NOT NULL,
   MODIFY last_insert_id INTEGER NOT NULL,
   MODIFY insert_id INTEGER NOT NULL,
   MODIFY server_id INTEGER UNSIGNED NOT NULL,
-  MODIFY sql_text MEDIUMTEXT NOT NULL;
-ALTER TABLE slow_log
-  ADD COLUMN thread_id BIGINT(21) UNSIGNED NOT NULL AFTER sql_text;
-ALTER TABLE slow_log
-  MODIFY thread_id BIGINT(21) UNSIGNED NOT NULL,
-  ADD COLUMN rows_affected BIGINT UNSIGNED NOT NULL AFTER thread_id;
+  MODIFY sql_text MEDIUMTEXT NOT NULL,
+  MODIFY thread_id BIGINT(21) UNSIGNED NOT NULL;
 SET GLOBAL slow_query_log = @old_log_state;
 
 ALTER TABLE plugin
@@ -846,8 +841,3 @@ IF 1 = (SELECT count(*) FROM information_schema.VIEWS WHERE TABLE_CATALOG = 'def
 END IF//
 
 DELIMITER ;
-
-# MDEV-22683 - upgrade Host and Owner of servers
-ALTER TABLE servers
-  MODIFY Host varchar(2048) NOT NULL DEFAULT '',
-  MODIFY Owner varchar(512) NOT NULL DEFAULT '';
