@@ -214,8 +214,8 @@ struct Geometry_buffer;
 class Geometry
 {
 public:
-  Geometry() = default;                              /* Remove gcc warning */
-  virtual ~Geometry() = default;                     /* Remove gcc warning */
+  Geometry() {}                               /* Remove gcc warning */
+  virtual ~Geometry() {}                        /* Remove gcc warning */
   static void *operator new(size_t size, void *buffer)
   {
     return buffer;
@@ -317,6 +317,7 @@ public:
                                     bool er_on_3D, String *res);
   static Geometry *create_from_opresult(Geometry_buffer *g_buf,
                                   String *res, Gcalc_result_receiver &rr);
+  static uint get_key_image_itMBR(LEX_CSTRING &src, uchar *buff, uint length);
   int as_wkt(String *wkt, const char **end);
   int as_json(String *wkt, uint max_dec_digits, const char **end);
   int bbox_as_json(String *wkt);
@@ -396,8 +397,8 @@ protected:
 class Gis_point: public Geometry
 {
 public:
-  Gis_point() = default;                              /* Remove gcc warning */
-  virtual ~Gis_point() = default;                     /* Remove gcc warning */
+  Gis_point() {}                              /* Remove gcc warning */
+  virtual ~Gis_point() {}                     /* Remove gcc warning */
   uint32 get_data_size() const;
   bool init_from_wkt(Gis_read_stream *trs, String *wkb);
   uint init_from_wkb(const char *wkb, uint len, wkbByteOrder bo, String *res);
@@ -466,8 +467,8 @@ public:
 class Gis_line_string: public Geometry
 {
 public:
-  Gis_line_string() = default;                        /* Remove gcc warning */
-  virtual ~Gis_line_string() = default;               /* Remove gcc warning */
+  Gis_line_string() {}                        /* Remove gcc warning */
+  virtual ~Gis_line_string() {}               /* Remove gcc warning */
   uint32 get_data_size() const;
   bool init_from_wkt(Gis_read_stream *trs, String *wkb);
   uint init_from_wkb(const char *wkb, uint len, wkbByteOrder bo, String *res);
@@ -499,8 +500,8 @@ public:
 class Gis_polygon: public Geometry
 {
 public:
-  Gis_polygon() = default;                            /* Remove gcc warning */
-  virtual ~Gis_polygon() = default;                   /* Remove gcc warning */
+  Gis_polygon() {}                            /* Remove gcc warning */
+  virtual ~Gis_polygon() {}                   /* Remove gcc warning */
   uint32 get_data_size() const;
   bool init_from_wkt(Gis_read_stream *trs, String *wkb);
   uint init_from_wkb(const char *wkb, uint len, wkbByteOrder bo, String *res);
@@ -536,8 +537,8 @@ class Gis_multi_point: public Geometry
     (uint32) (UINT_MAX32 - WKB_HEADER_SIZE - 4 /* n_points */) /
     (WKB_HEADER_SIZE + POINT_DATA_SIZE);
 public:
-  Gis_multi_point() = default;                        /* Remove gcc warning */
-  virtual ~Gis_multi_point() = default;               /* Remove gcc warning */
+  Gis_multi_point() {}                        /* Remove gcc warning */
+  virtual ~Gis_multi_point() {}               /* Remove gcc warning */
   uint32 get_data_size() const;
   bool init_from_wkt(Gis_read_stream *trs, String *wkb);
   uint init_from_wkb(const char *wkb, uint len, wkbByteOrder bo, String *res);
@@ -567,8 +568,8 @@ public:
 class Gis_multi_line_string: public Geometry
 {
 public:
-  Gis_multi_line_string() = default;                  /* Remove gcc warning */
-  virtual ~Gis_multi_line_string() = default;         /* Remove gcc warning */
+  Gis_multi_line_string() {}                  /* Remove gcc warning */
+  virtual ~Gis_multi_line_string() {}         /* Remove gcc warning */
   uint32 get_data_size() const;
   bool init_from_wkt(Gis_read_stream *trs, String *wkb);
   uint init_from_wkb(const char *wkb, uint len, wkbByteOrder bo, String *res);
@@ -598,8 +599,8 @@ public:
 class Gis_multi_polygon: public Geometry
 {
 public:
-  Gis_multi_polygon() = default;                      /* Remove gcc warning */
-  virtual ~Gis_multi_polygon() = default;             /* Remove gcc warning */
+  Gis_multi_polygon() {}                      /* Remove gcc warning */
+  virtual ~Gis_multi_polygon() {}             /* Remove gcc warning */
   uint32 get_data_size() const;
   bool init_from_wkt(Gis_read_stream *trs, String *wkb);
   uint init_from_wkb(const char *wkb, uint len, wkbByteOrder bo, String *res);
@@ -629,8 +630,8 @@ public:
 class Gis_geometry_collection: public Geometry
 {
 public:
-  Gis_geometry_collection() = default;                /* Remove gcc warning */
-  virtual ~Gis_geometry_collection() = default;       /* Remove gcc warning */
+  Gis_geometry_collection() {}                /* Remove gcc warning */
+  virtual ~Gis_geometry_collection() {}       /* Remove gcc warning */
   uint32 get_data_size() const;
   bool init_from_wkt(Gis_read_stream *trs, String *wkb);
   uint init_from_wkb(const char *wkb, uint len, wkbByteOrder bo, String *res);
